==> react-native-dl-bmkit-1.0.76.tgz: package/javascript/modules/video/video.tsx <==

/**
*   视频播放器
*/

import React, { useRef, useState } from 'react';
import { Platform, TouchableOpacity, View, ViewStyle } from 'react-native';
import { Slider } from 'react-native-elements';
import Video, { OnLoadData } from 'react-native-video';
import Icon from '../icon';

interface Props {

    /**
     *  设置视频源  
     */
    url: string

    /**
     *  视频view的样式
     */
    style: ViewStyle

    /**
     *  海报封面
     */
    poster?:string

    /**
     *  播放速率 默认是1
     */
    rate?: number

    /**
     *  是否暂停 默认false
     */
    paused?: boolean

    /**
     *  调节音量 默认是1
     */
    volume?: number

    /**
     *  控制是否静音 默认是false
     */
    muted?: boolean

    /**
     * 确定当帧与原始视频尺寸不匹配时如何调整视频的大小。默认 contain
     *  none:不应用调整大小 
     *  contain:保持纵横比 显示全 有黑边
     * cover：保持纵横比 显示不全 没黑边
     * stretch：强行填满，不保持纵横比
     */
    resizeMode?: 'none' | 'contain' | 'cover' | 'stretch'

    /**
     *  确定在到达结尾时是否重复播放视频。默认是false
     */
    repeat?: boolean

    /**
     *  是否显示全屏功能
     */
    fullscreen?:boolean
}

export default function VideoView(props: Readonly<Props>) {

    let { rate = 1, volume = 1, muted = false, resizeMode = 'contain', repeat = false, paused = true,poster ,fullscreen = Platform.OS == 'ios'} = props
    // 播放器
    const videoRef = useRef<Video>(null)
    // 是否正在播放
    const [player,setPlayer] = useState(!paused)
    // 视图宽度
    const [videoWidth,setVideoWidth] = useState(100)
    // 总时长
    const [duration,setDuration] = useState(0)
    // 当前时长
    const [currentPosition,setCurrentPosition] = useState(0)

    /**
     *  加载数据
     */
    const onLoad = (data: OnLoadData) => {
        // setDuration(data.duration)
        // console.log('加载数据',data)
        setDuration(data.duration);
    }

    /**
     *  开始加载视频时
     */
    const onLoadStart = ()=>{
        // console.log(' 组件加载后,开始加载视频')
    }

    /**
     *  视频已显示第一帧，封面 poster 被移除
     */
    const onReadyForDisplay = ()=>{
        // console.log(' 视频已显示第一帧，封面 poster 被移除        ')
    }

    /**
     *  视频元数据获取成功后
     */
    const onTimedMetadata = ()=>{
        // console.log('视频元数据获取成功后')
    }

    /**
     *  视频播放过程中的回调
     */
    const onProgress = (timeData: { currentTime: number, playableDuration: number, seekableDuration: number }) => {
        setCurrentPosition(timeData.currentTime)
        // console.log('视频播放过程中的回调',timeData.currentTime)
    }

    /**
     *  切换当前播放时间
     * currentTime:切换后当前播放时间
     * seekTime:切换的目标时间
     */
    const onSeek = (value:{currentTime:number,seekTime:number})=>{
        // console.log('切换当前播放时间',value.currentTime)
        setCurrentPosition(value.currentTime)
        // 当切换事件为0的
        if(value.currentTime === 0){
            // 暂停播放
            setPlayer(false)
        }
    }

    /**
     *  视频播放结束
     */
    const onEnd = () => {
        // console.log('视频播放结束')
        
        // 切换到最开始的位置
        videoRef.current?.seek(0);
    };

    /**
     *  播放按钮事件
     */
    const playerAction = ()=>{
        setPlayer(true)
    }

    /**
     *  暂停播放事件
     */
    const pausedAction = ()=>{
        setPlayer(false)
    }


     /// 进度条值改变
    const onSliderValueChange = (currentTime:number) =>{
        // console.log('滑块值 变化事件',currentTime)
        // setPlayer(false)
        // videoRef.current?.seek(currentTime);
    }


      /// 用户松开滑块
    const onSlidingComplete = (currentTime:number) =>{
        // console.log('滑块值 确定事件',currentTime)
        videoRef.current?.seek(currentTime);
    }

    // 全屏事件
    const fullscreenAction = ()=>{
        setPlayer(false)
        videoRef.current?.presentFullscreenPlayer();
    }

    const onLayout = (event: { nativeEvent: { layout: { width: number, height: number } } }) => {
        let videoWidth = event.nativeEvent.layout.width
        setVideoWidth(videoWidth)
        // console.log('视频组件宽度',videoWidth)
    }

    return (
        <View style={{ backgroundColor: '#000', ...props.style }}
            onLayout={onLayout}>
            <Video
                ref={videoRef}
                source={{ uri: props.url }}//设置视频源  
                style={{ flex: 1 }}//组件样式
                poster={poster}
                rate={rate}//播放速率
                paused={!player}//暂停
                volume={volume}//调节音量
                muted={muted}//控制音频是否静音
                resizeMode={resizeMode}//缩放模式
                onLoad={onLoad}//加载媒体并准备播放时调用的回调函数。
                onProgress={onProgress}//视频播放过程中每个间隔进度单位调用的回调函数
                onEnd={onEnd}//视频播放结束时的回调函数
                onLoadStart={onLoadStart}
                onReadyForDisplay={onReadyForDisplay}
                onTimedMetadata={onTimedMetadata}
                onSeek={onSeek}
                repeat={repeat}//确定在到达结尾时是否重复播放视频。
                controls={false}
            />

            {
                !player && (
                    <View style={{position:'absolute',left:0,top:0,right:0,bottom:0,justifyContent:'center',alignItems:'center',backgroundColor:'#rgba(0,0,0,0.4)'}}>
                        <Icon iconCode={0xe761} style={{color:'#fff',fontSize:videoWidth / 2}} onPress={playerAction} />
                    </View>
                )
            }

            {
                player && (
                    <View style={{position:'absolute',left:0,right:0,bottom:0,top:0}}>
                        <TouchableOpacity style={{flex:1}} onPress={pausedAction}  />
                        <View style={{height:videoWidth * 0.25,flexDirection:'row',alignItems:'center',backgroundColor:'#rgba(0,0,0,0.5)',paddingHorizontal:videoWidth * 0.05}}>
                            <Icon iconCode={0xe762} style={{color:'#fff',fontSize:videoWidth * 0.15}} onPress={pausedAction}  />
                            <Slider
                                style={{ flex: 1 ,marginHorizontal:videoWidth * 0.05}}
                                maximumTrackTintColor={"#999999"}
                                minimumTrackTintColor={"#00c06d"}
                                minimumValue={0}
                                maximumValue={duration}
                                value={currentPosition}
                                onSlidingComplete={onSlidingComplete}
                                onValueChange={onSliderValueChange}
                            />
                            { fullscreen && <Icon iconCode={0xe759} style={{color:'#fff',fontSize:videoWidth * 0.15}} onPress={fullscreenAction}  />}
                        </View>
                    </View>
                    
                )
            }
            

        </View>
    );

}

==> react-native-dl-bmkit-1.0.82.tgz: package/javascript/modules/video/video.tsx <==

/**
*   视频播放器
*/

import React, { useRef, useState } from 'react';
import { Platform, TouchableOpacity, View, ViewStyle } from 'react-native';
import { Slider } from 'react-native-elements';
import Video, { OnLoadData } from 'react-native-video';
import Icon from '../icon';

interface Props {

    /**
     *  设置视频源  
     */
    url: string

    /**
     *  视频view的样式
     */
    style: ViewStyle

    /**
     *  海报封面
     */
    poster?:string

    /**
     *  播放速率 默认是1
     */
    rate?: number

    /**
     *  是否暂停 默认false
     */
    paused?: boolean

    /**
     *  调节音量 默认是1
     */
    volume?: number

    /**
     *  控制是否静音 默认是false
     */
    muted?: boolean

    /**
     * 确定当帧与原始视频尺寸不匹配时如何调整视频的大小。默认 contain
     *  none:不应用调整大小 
     *  contain:保持纵横比 显示全 有黑边
     * cover：保持纵横比 显示不全 没黑边
     * stretch：强行填满，不保持纵横比
     */
    resizeMode?: 'none' | 'contain' | 'cover' | 'stretch'

    /**
     *  确定在到达结尾时是否重复播放视频。默认是false
     */
    repeat?: boolean

    /**
     *  是否显示全屏功能
     */
    fullscreen?:boolean
}

export default function VideoView(props: Readonly<Props>) {

    let { rate = 1, volume = 1, muted = false, resizeMode = 'contain', repeat = false, paused = true,poster ,fullscreen = Platform.OS == 'ios'} = props
    // 播放器
    const videoRef = useRef<Video>(null)
    // 是否正在播放
    const [player,setPlayer] = useState(!paused)
    // 视图宽度
    const [videoWidth,setVideoWidth] = useState(100)
    // 总时长
    const [duration,setDuration] = useState(0)
    // 当前时长
    const [currentPosition,setCurrentPosition] = useState(0)

    /**
     *  加载数据
     */
    const onLoad = (data: OnLoadData) => {
        // setDuration(data.duration)
        // console.log('加载数据',data)
        setDuration(data.duration);
    }

    /**
     *  开始加载视频时
     */
    const onLoadStart = ()=>{
        // console.log(' 组件加载后,开始加载视频')
    }

    /**
     *  视频已显示第一帧，封面 poster 被移除
     */
    const onReadyForDisplay = ()=>{
        // console.log(' 视频已显示第一帧，封面 poster 被移除        ')
    }

    /**
     *  视频元数据获取成功后
     */
    const onTimedMetadata = ()=>{
        // console.log('视频元数据获取成功后')
    }

    /**
     *  视频播放过程中的回调
     */
    const onProgress = (timeData: { currentTime: number, playableDuration: number, seekableDuration: number }) => {
        setCurrentPosition(timeData.currentTime)
        // console.log('视频播放过程中的回调',timeData.currentTime)
    }

    /**
     *  切换当前播放时间
     * currentTime:切换后当前播放时间
     * seekTime:切换的目标时间
     */
    const onSeek = (value:{currentTime:number,seekTime:number})=>{
        // console.log('切换当前播放时间',value.currentTime)
        setCurrentPosition(value.currentTime)
        // 当切换事件为0的
        if(value.currentTime === 0){
            // 暂停播放
            setPlayer(false)
        }
    }

    /**
     *  视频播放结束
     */
    const onEnd = () => {
        // console.log('视频播放结束')
        
        // 切换到最开始的位置
        videoRef.current?.seek(0);
    };

    /**
     *  播放按钮事件
     */
    const playerAction = ()=>{
        setPlayer(true)
    }

    /**
     *  暂停播放事件
     */
    const pausedAction = ()=>{
        setPlayer(false)
    }


     /// 进度条值改变
    const onSliderValueChange = (currentTime:number) =>{
        // console.log('滑块值 变化事件',currentTime)
        // setPlayer(false)
        // videoRef.current?.seek(currentTime);
    }


      /// 用户松开滑块
    const onSlidingComplete = (currentTime:number) =>{
        // console.log('滑块值 确定事件',currentTime)
        videoRef.current?.seek(currentTime);
    }

    // 全屏事件
    const fullscreenAction = ()=>{
        setPlayer(false)
        videoRef.current?.presentFullscreenPlayer();
    }

    const onLayout = (event: { nativeEvent: { layout: { width: number, height: number } } }) => {
        let videoWidth = event.nativeEvent.layout.width
        setVideoWidth(videoWidth)
        // console.log('视频组件宽度',videoWidth)
    }

    const iconSize = videoWidth * 0.15 > 20 ? 20 : videoWidth * 0.15

    return (
        <View style={{ backgroundColor: '#000', ...props.style }}
            onLayout={onLayout}>
            <Video
                ref={videoRef}
                source={{ uri: props.url }}//设置视频源  
                style={{ flex: 1 }}//组件样式
                poster={poster}
                rate={rate}//播放速率
                paused={!player}//暂停
                volume={volume}//调节音量
                muted={muted}//控制音频是否静音
                resizeMode={resizeMode}//缩放模式
                onLoad={onLoad}//加载媒体并准备播放时调用的回调函数。
                onProgress={onProgress}//视频播放过程中每个间隔进度单位调用的回调函数
                onEnd={onEnd}//视频播放结束时的回调函数
                onLoadStart={onLoadStart}
                onReadyForDisplay={onReadyForDisplay}
                onTimedMetadata={onTimedMetadata}
                onSeek={onSeek}
                repeat={repeat}//确定在到达结尾时是否重复播放视频。
                controls={false}
            />

            {
                !player && (
                    <View style={{position:'absolute',left:0,top:0,right:0,bottom:0,justifyContent:'center',alignItems:'center',backgroundColor:'#rgba(0,0,0,0.4)'}}>
                        <Icon iconCode={0xe761} style={{color:'#fff',fontSize:videoWidth / 2}} onPress={playerAction} />
                    </View>
                )
            }

            {
                player && (
                    <View style={{position:'absolute',left:0,right:0,bottom:0,top:0}}>
                        <TouchableOpacity style={{flex:1}} onPress={pausedAction}  />
                        <View style={{height:videoWidth * 0.25,maxHeight:50,flexDirection:'row',alignItems:'center',backgroundColor:'#rgba(0,0,0,0.5)',paddingHorizontal:8}}>
                            <Icon iconCode={0xe762} style={{color:'#fff',fontSize:iconSize}} onPress={pausedAction}  />
                            <Slider
                                style={{ flex: 1 ,marginHorizontal:8}}
                                maximumTrackTintColor={"#999999"}
                                minimumTrackTintColor={"#00c06d"}
                                minimumValue={0}
                                maximumValue={duration}
                                value={currentPosition}
                                onSlidingComplete={onSlidingComplete}
                                onValueChange={onSliderValueChange}
                            />
                            { fullscreen && <Icon iconCode={0xe759} style={{color:'#fff',fontSize:iconSize}} onPress={fullscreenAction}  />}
                        </View>
                    </View>
                    
                )
            }
        </View>
    );

}
